/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.idea.codeInsight;

import com.intellij.ide.util.DefaultPsiElementCellRenderer;
import com.intellij.psi.PsiElement;
import org.jetbrains.kotlin.descriptors.DeclarationDescriptor;
import org.jetbrains.kotlin.idea.caches.resolve.ResolvePackage;
import org.jetbrains.kotlin.psi.JetNamedFunction;
import org.jetbrains.kotlin.renderer.DescriptorRenderer;

public class JetFunctionPsiElementCellRenderer extends DefaultPsiElementCellRenderer {
    @Override
    public String getElementText(PsiElement element) {
        if (element instanceof JetNamedFunction) {
            JetNamedFunction function = (JetNamedFunction) element;
            DeclarationDescriptor descriptor = ResolvePackage.resolveToDescriptor(function);
            return DescriptorRenderer.SHORT_NAMES_IN_TYPES.render(descriptor);
        }
        return super.getElementText(element);
    }
}
